MailExpireDetail = {}
 
MailExpireDetail.name = "MailExpireDetail"
MailExpireDetail.version = 1
MailExpireDetail.default_vars = { min_days_expire = 3 }

local LAM = LibStub:GetLibrary("LibAddonMenu-2.0")

function MailExpireDetail:Initialize()
    MailExpireDetail.savedVariables = ZO_SavedVars:New("MailExpireDetail_SavedVariables", MailExpireDetail.version, nil, MailExpireDetail.default_vars)
    MailExpireDetail:CreateOptionsWindow()

    local zo = MAIL_INBOX.SetupInboxEntry

    MAIL_INBOX.SetupInboxEntry = function (self, control, data)
        zo(self, control, data)

        local d = data.expiresInDays

        if d <= MailExpireDetail.savedVariables.min_days_expire then
            local sub = data:GetFormattedSubject()

            if d == 0 then
                d = "<1"
            end

            local sub2 = "|cff0000(" .. d .. ")|r " .. sub

            GetControl(control, "Subject"):SetText(sub2)
        end
    end
end

function MailExpireDetail:CreateOptionsWindow()
    local panel = {
        type = "panel",
        name = "MailExpireDetail",
        author = "@noobanidus",
        version = "1.0.3",
        slashCommand = "/med",
        registerForRefresh = true,
    }

    local options = {
        [1] = {
            type = "slider",
            name = "Days to alert (<=)",
            tooltip = "Number of days before a mail expires before we place an alert.",
            min = 0,
            max = 30,
            getFunc = function() return MailExpireDetail.savedVariables.min_days_expire end,
            setFunc = function(val) MailExpireDetail.savedVariables.min_days_expire = val end,
        },
    }

    LAM:RegisterAddonPanel("MailExpireDetailOptsPanel", panel)
    LAM:RegisterOptionControls("MailExpireDetailOptsPanel", options)
end
 
function MailExpireDetail.OnAddOnLoaded(event, addonName)
    if addonName == MailExpireDetail.name then
        MailExpireDetail:Initialize()
    end
end
 
EVENT_MANAGER:RegisterForEvent(MailExpireDetail.name, EVENT_ADD_ON_LOADED, MailExpireDetail.OnAddOnLoaded)
